@@ -3,9 +3,9 @@ package Sah::Schema::dirname;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-11-23'; # DATE
+our $DATE = '2024-01-08'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.027'; # VERSION
+our $VERSION = '0.028'; # VERSION
 
 our $schema = [str => {
     summary => 'Filesystem directory name',
@@ -58,7 +58,26 @@ Sah::Schema::dirname - Filesystem directory name
 
 =head1 VERSION
 
-This document describes version 0.027 of Sah::Schema::dirname (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
+This document describes version 0.028 of Sah::Schema::dirname (from Perl distribution Sah-Schemas-Path), released on 2024-01-08.
+
+=head1 SAH SCHEMA DEFINITION
+
+ [
+   "str",
+   {
+     "min_len"      => 1,
+     "prefilters"   => [
+                         "Path::expand_tilde_when_on_unix",
+                         "Path::strip_slashes_when_on_unix",
+                       ],
+     "summary"      => "Filesystem directory name",
+     "x.completion" => ["dirname"],
+   },
+ ]
+
+Used prefilters: L<Path::expand_tilde_when_on_unix|Data::Sah::Filter::perl::Path::expand_tilde_when_on_unix>, L<Path::strip_slashes_when_on_unix|Data::Sah::Filter::perl::Path::strip_slashes_when_on_unix>
+
+Used completion: L<dirname|Perinci::Sub::XComplete::dirname>
 
 =head1 SYNOPSIS
 
@@ -247,7 +266,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2020, 2019, 2018, 2016 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2023, 2020, 2019, 2018, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
