@@ -4,9 +4,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-11-23'; # DATE
+our $DATE = '2024-01-08'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.027'; # VERSION
+our $VERSION = '0.028'; # VERSION
 
 our $schema = ['dirname' => {
     summary => 'Directory name, default to current directory',
@@ -41,7 +41,17 @@ Sah::Schema::dirname::default_curdir - Directory name, default to current direct
 
 =head1 VERSION
 
-This document describes version 0.027 of Sah::Schema::dirname::default_curdir (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
+This document describes version 0.028 of Sah::Schema::dirname::default_curdir (from Perl distribution Sah-Schemas-Path), released on 2024-01-08.
+
+=head1 SAH SCHEMA DEFINITION
+
+ [
+   "dirname",
+   {
+     default => ".",
+     summary => "Directory name, default to current directory",
+   },
+ ]
 
 =head1 SYNOPSIS
 
@@ -201,7 +211,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2020, 2019, 2018, 2016 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2023, 2020, 2019, 2018, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
