@@ -3,9 +3,9 @@ package Sah::Schema::dirname::exists::default_only_subdir_in_curdir;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-11-23'; # DATE
+our $DATE = '2024-01-08'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.027'; # VERSION
+our $VERSION = '0.028'; # VERSION
 
 our $schema = ["dirname::exists" => {
     summary => 'Directory name, must exist on the filesystem, defaults to only subdirectory in current directory (if there is one)',
@@ -39,7 +39,17 @@ Sah::Schema::dirname::exists::default_only_subdir_in_curdir - Directory name, mu
 
 =head1 VERSION
 
-This document describes version 0.027 of Sah::Schema::dirname::exists::default_only_subdir_in_curdir (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
+This document describes version 0.028 of Sah::Schema::dirname::exists::default_only_subdir_in_curdir (from Perl distribution Sah-Schemas-Path), released on 2024-01-08.
+
+=head1 SAH SCHEMA DEFINITION
+
+ [
+   "dirname::exists",
+   {
+     "summary" => "Directory name, must exist on the filesystem, defaults to only subdirectory in current directory (if there is one)",
+     "x.perl.default_value_rules" => ["Path::only_subdir_in_curdir"],
+   },
+ ]
 
 =head1 SYNOPSIS
 
@@ -199,7 +209,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2020, 2019, 2018, 2016 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2023, 2020, 2019, 2018, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
