@@ -3,9 +3,9 @@ package Sah::Schema::filename;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-11-23'; # DATE
+our $DATE = '2024-01-08'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.027'; # VERSION
+our $VERSION = '0.028'; # VERSION
 
 our $schema = [str => {
     summary => 'Filesystem file name',
@@ -58,7 +58,26 @@ Sah::Schema::filename - Filesystem file name
 
 =head1 VERSION
 
-This document describes version 0.027 of Sah::Schema::filename (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
+This document describes version 0.028 of Sah::Schema::filename (from Perl distribution Sah-Schemas-Path), released on 2024-01-08.
+
+=head1 SAH SCHEMA DEFINITION
+
+ [
+   "str",
+   {
+     "min_len"      => 1,
+     "prefilters"   => [
+                         "Path::expand_tilde_when_on_unix",
+                         "Path::strip_slashes_when_on_unix",
+                       ],
+     "summary"      => "Filesystem file name",
+     "x.completion" => ["filename"],
+   },
+ ]
+
+Used prefilters: L<Path::expand_tilde_when_on_unix|Data::Sah::Filter::perl::Path::expand_tilde_when_on_unix>, L<Path::strip_slashes_when_on_unix|Data::Sah::Filter::perl::Path::strip_slashes_when_on_unix>
+
+Used completion: L<filename|Perinci::Sub::XComplete::filename>
 
 =head1 SYNOPSIS
 
@@ -86,7 +105,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "foo/bar";
+ $data = "foo";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
@@ -101,8 +120,8 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "foo/bar";
- my $res = $validator->($data); # => ["","foo/bar"]
+ $data = "foo";
+ my $res = $validator->($data); # => ["","foo"]
  
  # a sample invalid data
  $data = "";
@@ -247,7 +266,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2020, 2019, 2018, 2016 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2023, 2020, 2019, 2018, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
