@@ -3,9 +3,9 @@ package Sah::Schema::filename::unix::basename;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-11-23'; # DATE
+our $DATE = '2024-01-08'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.027'; # VERSION
+our $VERSION = '0.028'; # VERSION
 
 our $schema = ["str" => {
     summary => 'Filesystem base file name on a Unix system',
@@ -46,7 +46,21 @@ Sah::Schema::filename::unix::basename - Filesystem base file name on a Unix syst
 
 =head1 VERSION
 
-This document describes version 0.027 of Sah::Schema::filename::unix::basename (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
+This document describes version 0.028 of Sah::Schema::filename::unix::basename (from Perl distribution Sah-Schemas-Path), released on 2024-01-08.
+
+=head1 SAH SCHEMA DEFINITION
+
+ [
+   "str",
+   {
+     "match"        => "\\A(?:[^/\\0]{1,255})\\z",
+     "prefilters"   => [],
+     "summary"      => "Filesystem base file name on a Unix system",
+     "x.completion" => ["filename_curdir"],
+   },
+ ]
+
+Used completion: L<filename_curdir|Perinci::Sub::XComplete::filename_curdir>
 
 =head1 SYNOPSIS
 
@@ -229,7 +243,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2020, 2019, 2018, 2016 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2023, 2020, 2019, 2018, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
