@@ -3,9 +3,9 @@ package Sah::Schema::filename::unix::exists;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-11-23'; # DATE
+our $DATE = '2024-01-08'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.027'; # VERSION
+our $VERSION = '0.028'; # VERSION
 
 our $schema = ["filename::unix" => {
     summary => 'Unix file name, must exist on filesystem',
@@ -35,7 +35,19 @@ Sah::Schema::filename::unix::exists - Unix file name, must exist on filesystem
 
 =head1 VERSION
 
-This document describes version 0.027 of Sah::Schema::filename::unix::exists (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
+This document describes version 0.028 of Sah::Schema::filename::unix::exists (from Perl distribution Sah-Schemas-Path), released on 2024-01-08.
+
+=head1 SAH SCHEMA DEFINITION
+
+ [
+   "filename::unix",
+   {
+     prefilters => ["Path::check_file_exists"],
+     summary    => "Unix file name, must exist on filesystem",
+   },
+ ]
+
+Used prefilters: L<Path::check_file_exists|Data::Sah::Filter::perl::Path::check_file_exists>
 
 =head1 SYNOPSIS
 
@@ -189,7 +201,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2020, 2019, 2018, 2016 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2023, 2020, 2019, 2018, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
