@@ -3,9 +3,9 @@ package Sah::Schema::pathname::unix::basename;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-11-23'; # DATE
+our $DATE = '2024-01-08'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.027'; # VERSION
+our $VERSION = '0.028'; # VERSION
 
 our $schema = ["str" => {
     summary => 'Filesystem base path name on a Unix system',
@@ -46,7 +46,21 @@ Sah::Schema::pathname::unix::basename - Filesystem base path name on a Unix syst
 
 =head1 VERSION
 
-This document describes version 0.027 of Sah::Schema::pathname::unix::basename (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
+This document describes version 0.028 of Sah::Schema::pathname::unix::basename (from Perl distribution Sah-Schemas-Path), released on 2024-01-08.
+
+=head1 SAH SCHEMA DEFINITION
+
+ [
+   "str",
+   {
+     "match"        => "\\A(?:[^/\\0]{1,255})\\z",
+     "prefilters"   => [],
+     "summary"      => "Filesystem base path name on a Unix system",
+     "x.completion" => ["pathname_curdir"],
+   },
+ ]
+
+Used completion: L<pathname_curdir|Perinci::Sub::XComplete::pathname_curdir>
 
 =head1 SYNOPSIS
 
@@ -78,7 +92,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample invalid data
- $data = "foo\0";
+ $data = "/";
  my $errmsg = $validator->($data); # => "Must match regex pattern \\A(?:[^/\\0]{1,255})\\z"
 
 Often a schema has coercion rule or default value rules, so after validation the
@@ -89,8 +103,8 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample invalid data
- $data = "foo\0";
- my $res = $validator->($data); # => ["Must match regex pattern \\A(?:[^/\\0]{1,255})\\z","foo\0"]
+ $data = "/";
+ my $res = $validator->($data); # => ["Must match regex pattern \\A(?:[^/\\0]{1,255})\\z","/"]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
@@ -221,7 +235,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2020, 2019, 2018, 2016 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2023, 2020, 2019, 2018, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
